@@ -7,33 +7,32 @@
 #'
 #' @keywords internal
 #'
-construct_variance <- function(fit, K = NULL, eta = NULL){
+construct_variance <- function(fit, K = NULL, eta = NULL) {
   # if 'fit' is given
-  if (!missing(fit)){
+  if (!missing(fit)) {
     K <- fit$K
-      # case 1: K is a matrix
-    if (is.matrix(K)){
-      Sigma_hat <- (fit$eta * K) + ((1-fit$eta) * diag(nrow(K)))
+    # case 1: K is a matrix
+    if (is.matrix(K)) {
+      Sigma_hat <- (fit$eta * K) + ((1 - fit$eta) * diag(nrow(K)))
     } else {
       # case 2: K is a list with U,s
       SUt <- sweep(t(K$U), MARGIN = 1, STATS = K$s, FUN = "*")
-      K_mat <- K$U%*%SUt
-      Sigma_hat <- (fit$eta * K_mat) + ((1-fit$eta) * diag(nrow(K_mat)))
+      K_mat <- K$U %*% SUt
+      Sigma_hat <- (fit$eta * K_mat) + ((1 - fit$eta) * diag(nrow(K_mat)))
     }
-  } else if (!is.null(K) & !is.null(eta)) {
-    if (is.matrix(K)){
-      Sigma_hat <- (eta * K) + ((1-eta) * diag(nrow(K)))
+  } else if (!is.null(K) && !is.null(eta)) {
+    if (is.matrix(K)) {
+      Sigma_hat <- (eta * K) + ((1 - eta) * diag(nrow(K)))
     } else {
       SUt <- sweep(t(K$U), MARGIN = 1, STATS = K$s, FUN = "*")
-      K_mat <- K$U%*%SUt
-      Sigma_hat <- (eta * K_mat) + ((1-eta) * diag(nrow(K$U)))
+      K_mat <- K$U %*% SUt
+      Sigma_hat <- (eta * K_mat) + ((1 - eta) * diag(nrow(K$U)))
     }
 
   } else {
     stop("\nOptions to construct_variance must be either: \n(1) supply a plmm object to
-         fit or \n(2) supply both K and eta arguments.")
+         fit or \n(2) supply both K and eta arguments.", call. = FALSE)
   }
 
   return(Sigma_hat)
 }
-
