@@ -10,7 +10,7 @@
 #' @param y               Optional: In the case where `design` is a `matrix` or `data.frame`, the user must also supply
 #'                        a numeric outcome vector as the `y` argument. In this case, `design` and `y` will be passed
 #'                        internally to `create_design(X = design, y = y)`.
-#' @param K               Similarity matrix used to rotate the data. This should either be (1) a known matrix that reflects the covariance of y, (2) an estimate (Default is \eqn{\frac{1}{p}(XX^T)}), or (3) a list with components 'd' and 'u', as returned by choose_k().
+#' @param K               Similarity matrix used to rotate the data. This should either be (1) a known matrix that reflects the covariance of y, (2) an estimate (Default is \eqn{\frac{1}{p}(XX^T)}), or (3) a list with components 's' and 'u', as returned by choose_k().
 #' @param diag_K          Logical: should K be a diagonal matrix? This would reflect observations that are unrelated, or that can be treated as unrelated. Defaults to FALSE.
 #'                        Note: plmm() does not check to see if a matrix is diagonal. If you want to use a diagonal K matrix, you must set diag_K = TRUE.
 #' @param eta_star        Optional argument to input a specific eta term rather than estimate it from the data. If K is a known covariance matrix that is full rank, this should be 1.
@@ -42,43 +42,41 @@
 #' @param return_fit      Optional: a logical value indicating whether the fitted model should be returned as a `plmm` object in the current (assumed interactive) session. Defaults to TRUE.
 #' @param ...             Additional arguments to `plmm_fit`
 #'
-#' @returns a list with 12 items:
+#' @returns A list that includes 15 items:
 #'
-#' * type: the type of prediction used ('lp' or 'blup')
-#' * cve: numeric vector with the cross validation error (CVE) at each value of `lambda`
-#' * cvse: numeric vector with the estimated standard error associated with each value of for `cve`
-#' * fold: numeric `n` length vector of integers indicating the fold to which each observation was assigned
-#' * lambda: numeric vector of `lambda` values
-#' * fit: the overall fit of the object, including all predictors; this is a
-#'  list as returned by `plmm()`
+#' * type: The type of prediction used ('lp' or 'blup')
+#' * cve: A numeric vector with the cross validation error (CVE) at each value of `lambda`
+#' * cvse: A numeric vector with the estimated standard error associated with each value of `cve`
+#' * fold: A numeric `n` length vector of integers indicating the fold to which each observation was assigned
+#' * lambda: A numeric vector of `lambda` values
+#' * fit: The overall fit of the object, including all predictors; this is a list as returned by `plmm()`
 #' * min: The index corresponding to the value of `lambda` that minimizes `cve`
-#' * lambda_min: The `lambda` value at which `cve` is minmized
-#' * min1se: The index corresponding to the value of `lambda` within
-#' standard error of that which minimizes `cve`
-#' * lambda1se: largest value of lambda such that error is within 1 standard error of the minimum.
-#' * null.dev: numeric value representing the deviance for the
-#'  intercept-only model. If you have supplied your own `lambda` sequence,
-#'  this quantity may not be meaningful.
-#' * estimated_Sigma: an n x n matrix representing the estimated covariance matrix.
-#' @export
+#' * lambda_min: The `lambda` value at which `cve` is minimized
+#' * min1se: The index corresponding to the value of `lambda` within 1 standard error of
+#'   that which minimizes `cve`
+#' * lambda1se: The largest value of lambda such that `cve` is within 1 standard error of the minimum
+#' * null.dev: A numeric value representing the deviance for the intercept-only model. If you have supplied
+#'   your own `lambda` sequence, this quantity may not be meaningful.
+#' * Y: A matrix with the predicted outcome (\eqn{\hat{y}}) values at each value of `lambda`.
+#'   Rows are observations, columns are values of `lambda`.
+#' * loss: A matrix with the loss values at each value of lambda. Rows are observations,
+#'   columns are values of `lambda`.
+#' * estimated_Sigma: An n x n matrix representing the estimated covariance matrix.
 #'
 #' @examples
 #' admix_design <- create_design(X = admix$X, y = admix$y)
 #' cv_fit <- cv_plmm(design = admix_design)
 #' print(summary(cv_fit))
 #' plot(cv_fit)
-#'
-#' # Note: for examples with filebacked data, see the filebacking vignette
-#' # https://pbreheny.github.io/plmmr/articles/filebacking.html
-#'
-#'
+#' @export
+
 cv_plmm <- function(design,
                     y = NULL,
                     K = NULL,
                     diag_K = NULL,
                     eta_star = NULL,
                     penalty = "lasso",
-                    type = 'blup',
+                    type = "blup",
                     gamma,
                     alpha = 1,
                     lambda_min, # passed to internal function setup_lambda()
@@ -89,39 +87,38 @@ cv_plmm <- function(design,
                     warn = TRUE,
                     init = NULL,
                     cluster,
-                    nfolds=5,
+                    nfolds = 5,
                     seed,
                     fold = NULL,
-                    trace=FALSE,
+                    trace = FALSE,
                     save_rds = NULL,
                     return_fit = TRUE,
                     ...) {
 
   # check filepaths for saving results ------------------------------
   if (!is.null(save_rds)) {
-    save_rds <- check_for_file_extension(save_rds)
-    # ^^ internally, we need to take off the extension from the file name
-
-    # start the log
+    save_rds <- tools::file_path_sans_ext(save_rds)
     logfile <- create_log(outfile = save_rds)
   }
 
   # create a design if needed -------------
-  if (inherits(design, "data.frame") | inherits(design, 'matrix')) {
+  if (inherits(design, "data.frame") || inherits(design, "matrix")) {
     # error check: if 'design' is matrix/data.frame, user must specify 'y'
     if (is.null(y)) {
-      stop("If you supply a matrix or data frame as 'design', you
-                         must also specify a numeric vector as the outcome of your
-                         model to the 'y' argument.")
+      stop(
+        "If you supply a matrix or data frame as 'design', you must also specify
+        a numeric vector as the outcome of your model to the 'y' argument.",
+        call. = FALSE
+      )
     }
-
     design <- create_design_in_memory(X = design, y = y)
-
-
-  } else {
-    if (!is.null(y)) stop("If you are supplying a plmm_design object or filepath to
-                          the 'design' argument, that design already has a 'y' --
-                          please do not specify a 'y' argument here in plmm()")
+  } else if (!is.null(y)) {
+    stop(
+      "If you are supplying a plmm_design object or filepath to the 'design'
+      argument, that design already has a 'y' -- do not specify a 'y' argument
+      here in plmm()",
+      call. = FALSE
+    )
   }
 
   # run data checks ------------------------------
@@ -136,7 +133,7 @@ cv_plmm <- function(design,
                               trace = trace,
                               ...)
 
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     cat("\nInput data passed all checks at ",
         pretty_time(),
         file = logfile, append = TRUE)
@@ -151,13 +148,13 @@ cv_plmm <- function(design,
                       centered_y = checked_data$centered_y,
                       K = checked_data$K,
                       diag_K = checked_data$diag_K,
-                      eta_star = eta_star,
+                      eta_star = checked_data$eta_star,
                       fbm_flag = checked_data$fbm_flag,
                       trace = trace))
 
-  prep <- do.call('plmm_prep', prep_args)
+  prep <- do.call("plmm_prep", prep_args)
 
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     cat("\nEigendecomposition finished at ",
         pretty_time(),
         file = logfile, append = TRUE)
@@ -168,7 +165,6 @@ cv_plmm <- function(design,
     prep = prep,
     y = checked_data$y,
     std_X_details = checked_data$std_X_details,
-    eta_star = eta_star,
     penalty_factor = checked_data$penalty_factor,
     fbm_flag = checked_data$fbm_flag,
     penalty = checked_data$penalty,
@@ -179,13 +175,13 @@ cv_plmm <- function(design,
     eps = eps,
     warn = warn))
 
-  if (!missing(lambda_min)){
+  if (!missing(lambda_min)) {
     fit_args$lambda_min <- lambda_min
   }
 
-  fit <- do.call('plmm_fit', fit_args)
+  fit <- do.call("plmm_fit", fit_args)
 
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     cat("\nFull model fit finished at",
         pretty_time(),
         file = logfile, append = TRUE)
@@ -197,7 +193,7 @@ cv_plmm <- function(design,
                                fbm_flag = checked_data$fbm_flag,
                                plink_flag = checked_data$plink_flag)
 
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     cat("\nFormatting for full model finished at",
         pretty_time(),
         file = logfile, append = TRUE)
@@ -219,13 +215,13 @@ cv_plmm <- function(design,
   cv_args$plink_flag <- checked_data$plink_flag
 
   estimated_Sigma <- NULL
-  if (type == 'blup') {
+  if (type == "blup") {
     estimated_Sigma <- construct_variance(eta = fit$eta, K = prep$K)
   }
 
   # initialize objects to hold CV results
   n <- checked_data$std_X_n
-  E <- Y <- matrix(NA, nrow=n, ncol=length(fit$lambda))
+  E <- Y <- matrix(NA, nrow = n, ncol = length(fit$lambda))
 
   # set up folds for cross validation
   if (!missing(seed)) {
@@ -234,15 +230,13 @@ cv_plmm <- function(design,
     set.seed(seed)
   }
 
-  sde <- sqrt(.Machine$double.eps)
-
   if (is.null(fold)) {
     if (trace) {
       cat("'Fold' argument is either NULL or missing; assigning folds randomly (by default).
           \nTo specify folds for each observation, supply a vector with fold assignments.\n")
     }
     fold <- sample(1:n %% nfolds)
-    fold[fold==0] <- nfolds
+    fold[fold == 0] <- nfolds
   } else {
     nfolds <- max(fold)
   }
@@ -251,28 +245,33 @@ cv_plmm <- function(design,
   if (!missing(cluster)) {
 
     # error check: parallelization is not yet implemented for filebacked data
-    if (checked_data$fbm_flag) stop("Parallelization is not yet implemented for filebacked data.
-                                    You cannot specify a 'cluster' argument if data are stored filebacked.\n.")
+    if (checked_data$fbm_flag) {
+      stop(
+        "Parallelization is not yet implemented for filebacked data. You cannot
+        specify a 'cluster' argument if data are stored filebacked.\n.",
+        call. = FALSE
+      )
+    }
 
     # check type of 'cluster' argument
-    if (!inherits(cluster, "cluster")) stop("cluster is not of class 'cluster'; see ?makeCluster", call.=FALSE)
+    if (!inherits(cluster, "cluster")) stop("cluster is not of class 'cluster'; see ?makeCluster", call. = FALSE)
 
     # check if variables are defined
     if (!exists("fold") || !exists("type") || !exists("cv_args")) {
-      stop("One or more required variables (fold, type, cv_args) are not defined", call.=FALSE)
+      stop("One or more required variables (fold, type, cv_args) are not defined", call. = FALSE)
     }
 
     parallel::clusterExport(cl = cluster,
                             varlist = c("fold", "type", "cv_args"),
                             envir = environment())
     parallel::clusterCall(cluster, function() library(plmmr))
-    fold_results <- parallel::parLapply(cl=cluster,
-                                        X=1:max(fold),
-                                        fun=cvf,
+    fold_results <- parallel::parLapply(cl = cluster,
+                                        X = 1:max(fold),
+                                        fun = cvf,
                                         design = design,
-                                        fold=fold,
-                                        type=type,
-                                        cv_args=cv_args)
+                                        fold = fold,
+                                        type = type,
+                                        cv_args = cv_args)
 
     # stop the cluster when done
     parallel::stopCluster(cluster)
@@ -282,24 +281,20 @@ cv_plmm <- function(design,
   # carry out CV -------------------------------------
   if (trace) cat("\nStarting cross validation\n")
 
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     cat("\nCross validation started at: ",
         pretty_time(),
         file = logfile,
         append = TRUE)
   }
 
-  # set up progress bar -- this can take a while
-  if(trace){pb <- utils::txtProgressBar(min = 0, max = nfolds, style = 3)}
   for (i in 1:nfolds) {
     # case 1: user-specified cluster
     if (!missing(cluster)) {
       res <- fold_results[[i]] # refers to lines from above
-      if (trace) {utils::setTxtProgressBar(pb, i)}
-
     } else {
       # case 2: cluster NOT user specified
-      if (!is.null(save_rds)){
+      if (!is.null(save_rds)) {
         cat("Started fold", i, "at", pretty_time(),
             file = logfile, append = TRUE)
       }
@@ -308,19 +303,15 @@ cv_plmm <- function(design,
                  fold = fold,
                  type = type,
                  cv_args = cv_args)
-      if (trace) {utils::setTxtProgressBar(pb, i)}
-
     }
 
-    if(trace) close(pb)
-
     # update E and Y
-    E[fold==i, 1:res$nl] <- res$loss
+    E[fold == i, 1:res$nl] <- res$loss
 
     if (!is.matrix(res$yhat)) {
       res$yhat <- as.matrix(res$yhat)
     }
-    Y[fold==i, 1:res$nl] <- res$yhat
+    Y[fold == i, 1:res$nl] <- res$yhat
 
     if (!is.null(save_rds)) {
       saveRDS(E, paste0(save_rds, "_loss.rds"))
@@ -337,12 +328,12 @@ cv_plmm <- function(design,
   # post-process results -----------------------------------------
   # eliminate saturated lambda values, if any
   ind <- which(apply(is.finite(E), 2, all)) # index for lambda values to keep
-  E <- E[, ind, drop=FALSE]
+  E <- E[, ind, drop = FALSE]
   Y <- Y[, ind]
   lambda <- fit$lambda[ind]
 
   # return min lambda idx
-  cve <- apply(E, 2, mean)
+  cve <- colMeans(E)
   cvse <- apply(E, 2, stats::sd) / sqrt(nrow(Y))
   min <- which.min(cve)
 
@@ -352,42 +343,41 @@ cv_plmm <- function(design,
   within1se <- which(cve >= l.se & cve <= u.se)
   min1se <- which.max(lambda %in% lambda[within1se])
 
-  # bias correction
-  e <- sapply(1:nfolds, function(i) apply(E[fold==i, , drop=FALSE], 2, mean))
-  Bias <- mean(e[min,] - apply(e, 2, min))
-
-  val <- list(type=type,
-              cve=cve,
-              cvse=cvse,
-              fold=fold,
-              lambda=lambda,
-              fit=fit_to_return,
-              min=min,
-              lambda_min=lambda[min],
+  val <- list(type = type,
+              cve = cve,
+              cvse = cvse,
+              fold = fold,
+              lambda = lambda,
+              fit = fit_to_return,
+              min = min,
+              lambda_min = lambda[min],
               min1se = min1se,
               lambda.1se = lambda[min1se],
-              null.dev=mean(plmm_loss(checked_data$y, rep(mean(checked_data$y), n))),
+              null.dev = mean(plmm_loss(checked_data$y, rep(mean(checked_data$y), n))),
               Y = Y,
-              bias = Bias,
               loss = E)
 
-  if (type == "blup"){
-    val$estimated_Sigma = estimated_Sigma
+  if (type == "blup") {
+    val$estimated_Sigma <- estimated_Sigma
   }
 
   # save output
-  if (!is.null(save_rds)){
+  if (!is.null(save_rds)) {
     saveRDS(val, paste0(save_rds, ".rds"))
-    cat("Results saved to:", paste0(save_rds, ".rds"), "at",
-        pretty_time(),
-        file = logfile, append = TRUE)
+    cat(
+      "Results saved to: ", paste0(save_rds, ".rds"), "at", pretty_time(),
+      file = logfile,
+      append = TRUE
+    )
   }
 
   # create a failsafe -- if save_rds is NULL, make sure return_fit = TRUE
-  if (is.null(save_rds) & !return_fit){
-    cat("You accidentally left save_rds = NULL and return_fit = FALSE;
-        to prevent you from losing your work, plmm() is returning the output as if return_fit = TRUE")
-
+  if (is.null(save_rds) && !return_fit) {
+    cat(
+      "You have specified `save_rds=NULL` and `return_fit=FALSE`; to prevent you
+      from losing your work, plmm() is returning the output as if
+      `return_fit=TRUE`"
+    )
     return_fit <- TRUE
   }
 
@@ -395,10 +385,7 @@ cv_plmm <- function(design,
   gc()
 
   # return ----------------------------------------------------------------
-  if (return_fit){
-    return(structure(val, class="cv_plmm"))
+  if (return_fit) {
+    return(structure(val, class = "cv_plmm"))
   }
-
-
-
 }
