@@ -20,11 +20,11 @@
 #' plot(fit, log.l = TRUE)
 
 ## from ncvreg
-plot.plmm <- function(x, alpha=1, log.l=FALSE, shade=TRUE, col, ...) {
-  if (length(x$lambda) == 1) stop("Model was fit with only a single lambda value; there is no path to plot", call.=FALSE)
-  YY <- if (length(x$penalty_factor)==nrow(x$beta_vals)) coef(x) else coef(x)[-1, , drop=FALSE]
-  penalized <- which(x$penalty_factor!=0)
-  nonzero <- which(apply(abs(YY), 1, sum)!=0)
+plot.plmm <- function(x, alpha = 1, log.l = FALSE, shade = TRUE, col, ...) {
+  if (length(x$lambda) == 1) stop("Model was fit with only a single lambda value; there is no path to plot", call. = FALSE)
+  YY <- if (length(x$penalty_factor) == nrow(x$beta_vals)) coef(x) else coef(x)[-1, , drop = FALSE]
+  penalized <- which(x$penalty_factor != 0)
+  nonzero <- which(apply(abs(YY), 1, sum) != 0)
   ind <- intersect(penalized, nonzero)
 
   # check for null model
@@ -32,34 +32,40 @@ plot.plmm <- function(x, alpha=1, log.l=FALSE, shade=TRUE, col, ...) {
     stop("\nNone of the penalized covariates ever take on nonzero values. Nothing to plot here...")
   }
 
-  Y <- YY[ind, , drop=FALSE]
+  Y <- YY[ind, , drop = FALSE]
   p <- nrow(Y)
   l <- x$lambda
 
   if (log.l) {
     l <- log(l)
     xlab <- expression(log(lambda))
-  } else xlab <- expression(lambda)
-  plot.args <- list(x=l, y=1:length(l), ylim=range(Y), xlab=xlab, ylab="", type="n", xlim=rev(range(l)), las=1)
+  } else {
+    xlab <- expression(lambda)
+  }
+
+  plot.args <- list(x = l, y = seq_along(l), ylim = range(Y), xlab = xlab, ylab = "",
+                    type = "n", xlim = rev(range(l)), las = 1)
   new.args <- list(...)
   if (length(new.args)) plot.args[names(new.args)] <- new.args
   do.call("plot", plot.args)
-  if (!is.element("ylab", names(new.args))) graphics::mtext(expression(hat(beta)), side=2, cex=graphics::par("cex"), line=3, las=1)
+  if (!is.element("ylab", names(new.args))) graphics::mtext(expression(hat(beta)),
+                                                            side = 2, cex = graphics::par("cex"), line = 3, las = 1)
 
-  if (shade & !is.null(x$convex.min)) {
+  if (shade && !is.null(x$convex.min)) {
     l1 <- l[x$convex.min]
     l2 <- min(l)
-    graphics::polygon(x=c(l1,l2,l2,l1), y=c(plot.args$ylim[1], plot.args$ylim[1], plot.args$ylim[2], plot.args$ylim[2]), col="gray85", border=FALSE)
+    graphics::polygon(x = c(l1, l2, l2, l1), y = c(plot.args$ylim[1], plot.args$ylim[1], plot.args$ylim[2], plot.args$ylim[2]),
+                      col = "gray85", border = FALSE)
   }
 
   if (missing(col)) {
-    col <- grDevices::hcl(h=seq(15, 375, len=max(4, p+1)), l=60, c=150, alpha=alpha)
-    col <- if (p==2) col[c(1,3)] else col[1:p]
+    col <- grDevices::hcl(h = seq(15, 375, len = max(4, p + 1)), l = 60, c = 150, alpha = alpha)
+    col <- if (p == 2) col[c(1, 3)] else col[1:p]
   } else {
     col <- col[ind]
   }
 
-  line.args <- list(col=col, lwd=1+2*exp(-p/20), lty=1)
+  line.args <- list(col = col, lwd = 1 + 2 * exp(-p/20), lty = 1)
   if (length(new.args)) line.args[names(new.args)] <- new.args
   line.args$x <- l
   # check types: Y may be filebacked, but in most cases it isn't that big...
@@ -69,5 +75,5 @@ plot.plmm <- function(x, alpha=1, log.l=FALSE, shade=TRUE, col, ...) {
   line.args$y <- t(Y)
   do.call("matlines", line.args)
 
-  graphics::abline(h=0)
+  graphics::abline(h = 0)
 }
