@@ -15,21 +15,26 @@
 #'
 #'
 standardize_filebacked <- function(X, new_file, rds_dir, non_gen, complete_outcome, id_var,
-                               outfile, quiet, overwrite){
+                                   outfile, quiet, overwrite, tocenter = TRUE) {
 
   # standardization ------------------------------------------------
-  if (!quiet) {cat("Column-standardizing the design matrix...\n")}
+  if (!quiet) {
+    cat("Column-standardizing the design matrix...\n")
+  }
   # centering & scaling
   # NOTE: this C++ call will change the .bk file so that its data are column-standardized
   std_res <- .Call("big_std",
                    X@address,
                    as.integer(count_cores()),
+                   tocenter,
                    NULL, # no center values to pass here -- will calculate these
                    NULL, # no scaling values to pass -- will calculate these
                    PACKAGE = "plmmr")
-X@address <- std_res$std_X # saves standardized .bk
-# TODO: pick up here -- what to do about file names here... the same .bk is being modified..
-  if (!quiet) {cat("Standardization completed at", pretty_time())}
+  X@address <- std_res$std_X # saves standardized .bk
+  # TODO: pick up here -- what to do about file names here... the same .bk is being modified..
+  if (!quiet) {
+    cat("Standardization completed at", pretty_time())
+  }
 
   cat("Standardization completed at", pretty_time(), file = outfile, append = TRUE)
 
@@ -46,7 +51,7 @@ X@address <- std_res$std_X # saves standardized .bk
   )
 
 
-  if (!quiet){
+  if (!quiet) {
     cat("Done with standardization. File formatting in progress\n")
   }
 
